<?php

/**
 * This class attempts to test public methods in object_nacoma_Model.
 *
 * Since it isn't feasible to unit test the object_nacoma_Model directly we
 * extract the parts we want to isolate and test and put the into nacoma_object,
 * a helper class with static methods.
 */
class objectnacoma_Test extends PHPUnit_Framework_TestCase {

	/**
	 * Test the helper method nacoma_object::remove_invisible_props.
	 */
	public function test_remove_invisible_props() {
		if (!class_exists('nacoma_object')) {
			require_once(__DIR__ . '/../../nacoma/helpers/nacoma_object.php');
		}

		// Visible properties will be same for all asserts.
		$visible_props = array(
			'host_name',
			'hostgroup_name',
			'template',
			'service_description'
		);

		// Assert only visible properties are left in $obj_vals.
		$obj_vals = $this->get_obj_vals();
		nacoma_object::remove_invisible_props(
			'new', null, $obj_vals, $visible_props
		);

		$result_vals = array(
			'host_name' =>           '',
			'hostgroup_name' =>      '',
			'template' =>            '',
			'service_description' => ''
		);
		$this->assertSame($result_vals, $obj_vals);

		// Assert that $obj_vals isn't affected when $id != "new".
		$obj_vals = $this->get_obj_vals();
		$result_vals = $obj_vals;
		nacoma_object::remove_invisible_props(
			1, null, $obj_vals, $visible_props
		);
		$this->assertSame($result_vals, $obj_vals);

		// Assert that $obj_vals isn't affected when $clone_id is set.
		$obj_vals = $this->get_obj_vals();
		$result_vals = $obj_vals;
		nacoma_object::remove_invisible_props(
			'new', 2, $obj_vals, $visible_props
		);
		$this->assertSame($result_vals, $obj_vals);

		// Assert that $obj_vals isn't affected when $visible_props is null.
		$obj_vals = $this->get_obj_vals();
		$result_vals = $obj_vals;
		nacoma_object::remove_invisible_props('new', null, $obj_vals, null);
		$this->assertSame($result_vals, $obj_vals);
	}

	private function get_obj_vals() {
		return array(
			'host_name' =>           '',
			'hostgroup_name' =>      '',
			'template' =>            '',
			'service_description' => '',
			'check_command' =>       '',
			'check_command_args' =>  '',
			'contact_groups' =>      '',
			'file_id' =>             ''
		);
	}

}
